]> git.decadent.org.uk Git - dak.git/blobdiff - katie.py
natalie got renamed
[dak.git] / katie.py
index 8d31d653a5f3391de9e27a046d70965897370727..b2ac53a940b0e205d8da65346662a7683743f588 100644 (file)
--- a/katie.py
+++ b/katie.py
@@ -2,7 +2,7 @@
 
 # Utility functions for katie
 # Copyright (C) 2001  James Troup <james@nocrew.org>
-# $Id: katie.py,v 1.13 2002-04-20 13:13:32 troup Exp $
+# $Id: katie.py,v 1.17 2002-04-29 22:00:44 troup Exp $
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 ###############################################################################
 
-import cPickle, errno, os, pg, re, stat, string, sys, time;
+import cPickle, errno, os, pg, re, stat, string, sys, tempfile, time;
 import utils, db_access;
 import apt_inst, apt_pkg;
 
@@ -288,6 +288,8 @@ class Katie:
 
             if action:
                 Subst["__ANNOUNCE_LIST_ADDRESS__"] = list;
+                if Cnf.get("Dinstall::TrackingServer") and changes["architecture"].has_key("source"):
+                    Subst["__ANNOUNCE_LIST_ADDRESS__"] = Subst["__ANNOUNCE_LIST_ADDRESS__"] + "\nBcc: %s@%s" % (changes["source"], Cnf["Dinstall::TrackingServer"])
                 mail_message = utils.TemplateSubst(Subst,open(Cnf["Dir::TemplatesDir"]+"/jennifer.announce","r").read());
                 utils.send_mail (mail_message, "")
 
@@ -357,33 +359,37 @@ class Katie:
             utils.send_mail(mail_message, "")
             self.announce(short_summary, 1)
 
-        ## FIXME: this should go away to some Debian specific file
-        # If we're accepting something for unstable do extra work to
-        # make it auto-buildable from accepted
-        if self.pkg.changes["distribution"].has_key("unstable"):
+        # Special support to enable clean auto-building of accepted packages
+        if Cnf.get("Dinstall::SpecialAcceptedAutoBuild") and \
+           self.pkg.changes["distribution"].has_key("unstable"):
             self.projectB.query("BEGIN WORK");
-            # Add it to the list of packages for later processing by apt-ftparchive
             for file in file_keys:
-                if files[file]["type"] == "dsc" or files[file]["type"] == "deb":
-                    filename = os.path.join(Cnf["Dir::QueueAcceptedDir"], file);
-                    self.projectB.query("INSERT INTO unstable_accepted (filename) VALUES ('%s')" % (filename));
-            # If the .orig.tar.gz is in the pool, create a symlink (if
-            # one doesn't already exist)
+                src = os.path.join(Cnf["Dir::QueueAcceptedDir"], file);
+                dest = os.path.join(Cnf["Dir::AcceptedAutoBuild"], file);
+                # Create a symlink to it
+                os.symlink(src, dest);
+                # Add it to the list of packages for later processing by apt-ftparchive
+                self.projectB.query("INSERT INTO unstable_accepted (filename, in_accepted) VALUES ('%s', 't')" % (dest));
+            # If the .orig.tar.gz is in the pool, create a symlink to
+            # it (if one doesn't already exist)
             if self.pkg.orig_tar_id:
                 # Determine the .orig.tar.gz file name
                 for dsc_file in self.pkg.dsc_files.keys():
                     if dsc_file[-12:] == ".orig.tar.gz":
                         filename = dsc_file;
-                dest = os.path.join(Cnf["Dir::QueueAcceptedDir"],filename);
+                dest = os.path.join(Cnf["Dir::AcceptedAutoBuild"],filename);
                 # If it doesn't exist, create a symlink
                 if not os.path.exists(dest):
                     # Find the .orig.tar.gz in the pool
-                    q = self.projectB.query("SELECT l.path, f.filename from location l, files f WHERE f.id = %s" % (self.pkg.orig_tar_id));
+                    q = self.projectB.query("SELECT l.path, f.filename from location l, files f WHERE f.id = %s and f.location = l.id" % (self.pkg.orig_tar_id));
                     ql = q.getresult();
                     if not ql:
                         utils.fubar("[INTERNAL ERROR] Couldn't find id %s in files table." % (self.pkg.orig_tar_id));
                     src = os.path.join(ql[0][0], ql[0][1]);
                     os.symlink(src, dest);
+                    # Add it to the list of packages for later processing by apt-ftparchive
+                    self.projectB.query("INSERT INTO unstable_accepted (filename, in_accepted) VALUES ('%s', 't')" % (dest));
+
             self.projectB.query("COMMIT WORK");
 
     ###########################################################################
@@ -459,10 +465,38 @@ class Katie:
             # safely overwrite it.
             utils.move(file, dest_file, 1, perms=0660);
 
-
     ###########################################################################
 
     def do_reject (self, manual = 0, reject_message = ""):
+        # If we weren't given a manual rejection message, spawn an
+        # editor so the user can add one in...
+        if manual and not reject_message:
+            temp_filename = tempfile.mktemp();
+            fd = os.open(temp_filename, os.O_RDWR|os.O_CREAT|os.O_EXCL, 0700);
+            os.close(fd);
+            editor = os.environ.get("EDITOR","vi")
+            answer = 'E';
+            while answer == 'E':
+                os.system("%s %s" % (editor, temp_filename))
+                file = utils.open_file(temp_filename);
+                reject_message = string.join(file.readlines());
+                file.close();
+                print "Reject message:";
+                print utils.prefix_multi_line_string(reject_message,"  ");
+                prompt = "[R]eject, Edit, Abandon, Quit ?"
+                answer = "XXX";
+                while string.find(prompt, answer) == -1:
+                    answer = utils.our_raw_input(prompt);
+                    m = re_default_answer.search(prompt);
+                    if answer == "":
+                        answer = m.group(1);
+                    answer = string.upper(answer[:1]);
+            os.unlink(temp_filename);
+            if answer == 'A':
+                return 1;
+            elif answer == 'Q':
+                sys.exit(0);
+
         print "Rejecting.\n"
 
         Cnf = self.Cnf;
@@ -502,20 +536,12 @@ class Katie:
             os.write(fd, reject_mail_message);
             os.close(fd);
 
-            # If we weren't given a manual rejection message, spawn an
-            # editor so the user can add one in...
-            if reject_message == "":
-                editor = os.environ.get("EDITOR","vi")
-                result = os.system("%s +6 %s" % (editor, reject_filename))
-                if result != 0:
-                    utils.fubar("editor invocation failed for '%s'!" % (reject_filename), result);
-               reject_mail_message = utils.open_file(reject_filename).read();
-
         # Send the rejection mail if appropriate
         if not Cnf["Dinstall::Options::No-Mail"]:
             utils.send_mail (reject_mail_message, "");
 
         self.Logger.log(["rejected", pkg.changes_file]);
+        return 0;
 
     ################################################################################